@@ -11,7 +11,9 @@ from onnx2tf.utils.common_functions import (
     print_node_info,
     inverted_operation_enable_disable,
     make_tf_node_info,
-    channel_transpose,
+    explicit_broadcast,
+    pre_process_transpose,
+    post_process_transpose,
 )
 
 
@@ -88,16 +90,26 @@ def make_node(
         np.int64,
     ]
 
-    if not isinstance(input_tensor_1, np.ndarray):
-        input_tensor_2 = channel_transpose(
-            const_or_var_1=input_tensor_1,
-            const_or_var_2=input_tensor_2,
-        )
-    else:
-        input_tensor_1 = channel_transpose(
-            const_or_var_1=input_tensor_2,
-            const_or_var_2=input_tensor_1,
-        )
+    input_tensor_1, input_tensor_2 = explicit_broadcast(
+        const_or_var_1=input_tensor_1,
+        const_or_var_2=input_tensor_2,
+        graph_node=graph_node,
+        tf_layers_dict= tf_layers_dict,
+    )
+
+    # Pre-process transpose
+    input_tensor_1 = pre_process_transpose(
+        value_before_transpose=input_tensor_1,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+    input_tensor_2 = pre_process_transpose(
+        value_before_transpose=input_tensor_2,
+        param_target='inputs',
+        param_name=graph_node.inputs[1].name,
+        **kwargs,
+    )
 
     # TFLite does not support TrueDiv(INT), so TrueDiv is avoided if possible
     x_is_integer = input_tensor_1.dtype in target_cast_dtype
@@ -110,6 +122,14 @@ def make_node(
         name=graph_node.name,
     )
 
+    # Post-process transpose
+    tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
+        value_before_transpose=divided_tensor,
+        param_target='outputs',
+        param_name=graph_node.outputs[0].name,
+        **kwargs,
+    )
+
     if xy_is_integer and dtype in target_cast_dtype:
         divided_tensor = tf.cast(divided_tensor, dtype=dtype)
 
